@@ -3,7 +3,7 @@ package App::ClusterSSH;
 use 5.008.004;
 use warnings;
 use strict;
-use version; our $VERSION = version->new('4.08');
+use version; our $VERSION = version->new('4.09');
 
 use Carp qw/cluck :DEFAULT/;
 
@@ -996,23 +996,31 @@ sub retile_hosts {
         );
     }
 
-    $self->config->dump("noexit") if ( $self->options->debug > 1 );
+    $self->config->dump("noexit") if ( $self->options->debug_level > 1 );
 
     # now find the size of the window decorations
     if ( !exists( $self->config->{internal_terminal_wm_decoration_left} ) ) {
 
-        # use the first window as exemplary
-        my ($wid) = $servers{ ( keys(%servers) )[0] }{wid};
+   # Debian #842965 (https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=842965)
+   # disable behavior added in https://github.com/duncs/clusterssh/pull/66
+   # unless explicitly enabled with auto_wm_decoration_offsets => yes
 
-        if ( defined($wid) ) {
+        if ( $self->config->{auto_wm_decoration_offsets} =~ /yes/i ) {
 
-            # get the WM decoration sizes
-            (   $self->config->{internal_terminal_wm_decoration_left},
-                $self->config->{internal_terminal_wm_decoration_right},
-                $self->config->{internal_terminal_wm_decoration_top},
-                $self->config->{internal_terminal_wm_decoration_bottom}
-                )
-                = X11::Protocol::WM::get_net_frame_extents( $xdisplay, $wid );
+            # use the first window as exemplary
+            my ($wid) = $servers{ ( keys(%servers) )[0] }{wid};
+
+            if ( defined($wid) ) {
+
+                # get the WM decoration sizes
+                (   $self->config->{internal_terminal_wm_decoration_left},
+                    $self->config->{internal_terminal_wm_decoration_right},
+                    $self->config->{internal_terminal_wm_decoration_top},
+                    $self->config->{internal_terminal_wm_decoration_bottom}
+                    )
+                    = X11::Protocol::WM::get_net_frame_extents( $xdisplay,
+                    $wid );
+            }
         }
 
         # in case the WM call failed we set some defaults
@@ -1149,7 +1157,7 @@ sub capture_terminal() {
     my ($self) = @_;
     $self->debug( 0, "Stub for capturing a terminal window" );
 
-    return if ( $self->coptions->debug < 6 );
+    return if ( $self->options->debug_level < 6 );
 
     # should never see this - all experimental anyhow
 
@@ -1387,7 +1395,7 @@ sub setup_repeat() {
                 if ( defined( $servers{$svr}{pid} ) ) {
                     if ( !kill( 0, $servers{$svr}{pid} ) ) {
                         $build_menu = 1;
-                        push( @dead_hosts, $servers{$svr}{givenname} );
+                        push( @dead_hosts, $servers{$svr}{connect_string} );
                         delete( $servers{$svr} );
                         $self->debug( 0, "$svr session closed" );
                     }
@@ -2371,7 +2379,7 @@ Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 1999-2015 Duncan Ferguson, all rights reserved.
+Copyright 1999-2016 Duncan Ferguson, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
