@@ -74,6 +74,7 @@ my %default_config = (
     sftp         => 'sftp',
     sftp_args    => "",
 
+    extra_tag_file           => '',
     extra_cluster_file       => '',
     external_cluster_command => '',
 
@@ -84,6 +85,7 @@ my %default_config = (
     history_height => 10,
 
     command             => q{},
+    hide_menu           => 0,
     max_host_menu_items => 30,
 
     macros_enabled   => 'yes',
@@ -97,10 +99,13 @@ my %default_config = (
     menu_send_autotearoff          => 0,
     menu_host_autotearoff          => 0,
 
+    unique_servers    => 0,
     use_all_a_records => 0,
 
     send_menu_xml_file => $ENV{HOME} . '/.clusterssh/send_menu',
 
+    auto_wm_decoration_offsets => "no",    # Debian #842965
+
     # don't set username here as takes precendence over ssh config
     user => '',
 );
@@ -184,8 +189,12 @@ sub validate_args {
     }
 
     # check the terminal has been found correctly
+    # looking for the terminal should not be fatal
     if ( !-e $self->{terminal} ) {
-        $self->{terminal} = $self->find_binary( $self->{terminal} );
+        eval { $self->{terminal} = $self->find_binary( $self->{terminal} ); };
+        if ($@) {
+            warn $@->message;
+        }
     }
 
     return $self;
@@ -484,7 +493,7 @@ sub dump {
     my ( $self, $no_exit, ) = @_;
 
     $self->debug( 3, 'Dumping config to STDOUT' );
-    print( '# Configuration dump produced by "cssh -u"', $/ );
+    print( '# Configuration dump produced by "cssh -d"', $/ );
 
     foreach my $key ( sort keys %$self ) {
         my $comment = '';
@@ -569,7 +578,7 @@ Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 1999-2015 Duncan Ferguson.
+Copyright 1999-2016 Duncan Ferguson.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
